@@ -19,8 +19,8 @@
 ################################################################################
 
 
-plot.timeSeries <-
-    function(x, y = NULL, FinCenter = NULL,
+setMethod("plot", "timeSeries",
+    function(x, y, FinCenter = NULL,
     plot.type = c("multiple", "single"),
     format = "auto", at = "auto",
     widths = 1, heights = 1,
@@ -52,6 +52,9 @@ plot.timeSeries <-
 
     # FUNCTION:
 
+    #
+    if (missing(y)) y <- NULL
+
     # Labels:
     xlabel <- if (!missing(x)) deparse(substitute(x))
     ylabel <- if (!missing(y)) deparse(substitute(y))
@@ -69,8 +72,10 @@ plot.timeSeries <-
         xlabel, ylabel = ylabel, axes = axes, mar.multi = mar.multi,
         oma.multi = oma.multi, yax.flip = yax.flip,
         format = format, at = at, widths = widths, heights = heights, ...)
-}
+})
 
+# until UseMethod dispatches S4 methods in 'base' functions
+plot.timeSeries <- function(x, y, ...) timeSeries::plot(x, y, ...)
 
 # ------------------------------------------------------------------------------
 # Internal Function called by plot():
@@ -266,6 +271,10 @@ setMethod("lines", "timeSeries",
     invisible(x)
 })
 
+# until UseMethod dispatches S4 methods in 'base' functions
+lines.timeSeries <- function(x, FinCenter = NULL, ...)
+    timeSeries::lines(x, FinCenter = FinCenter, ...)
+
 # ------------------------------------------------------------------------------
 
 setMethod("points", "timeSeries",
@@ -299,4 +308,8 @@ setMethod("points", "timeSeries",
     invisible(x)
 })
 
+# until UseMethod dispatches S4 methods in 'base' functions
+points.timeSeries <- function(x, FinCenter = NULL, ...)
+    timeSeries::points(x, FinCenter = FinCenter, ...)
+
 ################################################################################
